.selector-container {
    padding: 5px;
    border-bottom: 1px solid #ddd;
    margin-bottom: 20px;
  }
  
  .current-selection-text {
    margin-bottom: 10px;
  }
  
  .selected-elements {
    margin-bottom: 10px;
  }
  
  .element {
    display: flex;
    align-items: center;
    padding: 5px;
    border: 1px solid #ddd;
    border-radius: 5px;
    margin-right: 5px;
  }
  
  .remove-button {
    margin-left: 10px;
    cursor: pointer;
    background-color: #ff6666;
    border: none;
    border-radius: 3px;
    padding: 3px 5px;
    color: white;
  }
  
  .remove-button:hover {
    background-color: #cc0000;
  }
  
  .element-selector {
    margin-right: 10px;
  }
  
  #add-button {
    padding: 5px 10px;
    border: 1px solid #ddd;
    border-radius: 5px;
    cursor: pointer;
  }
  