.jp-Notebook {
    padding-top: 70px !important;
    overflow: auto;

    /* Adjust this value if needed */
}

.jp-Toolbar {
    position: fixed;
    overflow: auto;

    /* Ensure the toolbar is properly positioned */
    z-index: 1;
    /* Make sure the toolbar stays on top */
}